Stan Math Library: boost::math Namespace Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

Functions
boost::math Namespace Reference

Reimplmeneting boost functionality for `stan::math::var` and and bugs in classification of integer types. More...

## Functions
template<>
int | fpclassify (const stan::math::var &v)
| Categorizes the given stan::math::var value. More...
template<>
bool | isfinite (const stan::math::var &v)
| Checks if the given number has finite value. More...
template<>
bool | isinf (const stan::math::var &v)
| Checks if the given number is infinite. More...
template<>
bool | isnan (const stan::math::var &v)
| Checks if the given number is NaN. More...
template<>
bool | isnormal (const stan::math::var &v)
| Checks if the given number is normal. More...

## Detailed Description

Reimplmeneting boost functionality for `stan::math::var` and and bugs in classification of integer types.

FIXME: remove when BOOST fixes isfinite(). See ticket #6517. (Boost 1.48.0) https://svn.boost.org/trac/boost/ticket/6517

## Function Documentation

template<>

int boost::math::fpclassify | ( | const stan::math::var & | v | ) |
| inline

Categorizes the given stan::math::var value.

Categorizes the stan::math::var value, v, into the following categories: zero, subnormal, normal, infinite, or NAN.

Parameters

  v | Variable to classify.

Returns
  One of `FP_ZERO`, `FP_NORMAL`, `FP_FINITE`, `FP_INFINITE`, `FP_NAN`, or `FP_SUBZERO`, specifying the category of v.

Definition at line 24 of file boost_fpclassify.hpp.

template<>

bool boost::math::isfinite | ( | const stan::math::var & | v | ) |
| inline

Checks if the given number has finite value.

Return `true` if the specified variable's value is finite.

Parameters

  v | Variable to test.

Returns
  `true` if variable is finite.

Definition at line 22 of file boost_isfinite.hpp.

template<>

bool boost::math::isinf | ( | const stan::math::var & | v | ) |
| inline

Checks if the given number is infinite.

Return `true` if the specified variable's value is infinite.

Parameters

  v | Variable to test.

Returns
  `true` if variable is infinite.

Definition at line 22 of file boost_isinf.hpp.

template<>

bool boost::math::isnan | ( | const stan::math::var & | v | ) |
| inline

Checks if the given number is NaN.

Return `true` if the specified variable has a value that is NaN.

Parameters

  v | Variable to test.

Returns
  `true` if variable is NaN.

Definition at line 22 of file boost_isnan.hpp.

template<>

bool boost::math::isnormal | ( | const stan::math::var & | v | ) |
| inline

Checks if the given number is normal.

Return `true` if the specified variable has a value that is normal.

Parameters

  v | Variable to test.

Returns
  `true` if variable is normal.

Definition at line 22 of file boost_isnormal.hpp.

[ Stan Home Page ] © 2011–2016, Stan Development Team.